@@ -14,7 +14,6 @@
 #include <QUrlQuery>
 #include <syndication/atom/atom.h>
 #include <syndication/documentsource.h>
-#include <syndication_export.h>
 
 #include <knewstuffcore_debug.h>
 
@@ -27,11 +26,11 @@ static const QLatin1String OPDS_REL_AC_OPEN_ACCESS{"http://opds-spec.org/acquisi
 static const QLatin1String OPDS_REL_AC_BORROW{"http://opds-spec.org/acquisition/borrow"};
 static const QLatin1String OPDS_REL_AC_BUY{"http://opds-spec.org/acquisition/buy"};
 static const QLatin1String OPDS_REL_AC_SUBSCRIBE{"http://opds-spec.org/acquisition/subscribe"};
-static const QLatin1String OPDS_REL_AC_SAMPLE{"http://opds-spec.org/acquisition/sample"};
+// static const QLatin1String OPDS_REL_AC_SAMPLE{"http://opds-spec.org/acquisition/sample"};
 static const QLatin1String OPDS_REL_IMAGE{"http://opds-spec.org/image"};
 static const QLatin1String OPDS_REL_THUMBNAIL{"http://opds-spec.org/image/thumbnail"};
 static const QLatin1String OPDS_REL_CRAWL{"http://opds-spec.org/crawlable"};
-static const QLatin1String OPDS_REL_FACET{"http://opds-spec.org/facet"};
+// static const QLatin1String OPDS_REL_FACET{"http://opds-spec.org/facet"};
 static const QLatin1String OPDS_REL_SHELF{"http://opds-spec.org/shelf"};
 static const QLatin1String OPDS_REL_SORT_NEW{"http://opds-spec.org/sort/new"};
 static const QLatin1String OPDS_REL_SORT_POPULAR{"http://opds-spec.org/sort/popular"};
@@ -39,32 +38,32 @@ static const QLatin1String OPDS_REL_FEATURED{"http://opds-spec.org/featured"};
 static const QLatin1String OPDS_REL_RECOMMENDED{"http://opds-spec.org/recommended"};
 static const QLatin1String OPDS_REL_SUBSCRIPTIONS{"http://opds-spec.org/subscriptions"};
 static const QLatin1String OPDS_EL_PRICE{"opds:price"};
-static const QLatin1String OPDS_EL_INDIRECT{"opds:indirectAcquisition"};
-static const QLatin1String OPDS_ATTR_FACET_GROUP{"opds:facetGroup"};
-static const QLatin1String OPDS_ATTR_ACTIVE_FACET{"opds:activeFacet"};
+// static const QLatin1String OPDS_EL_INDIRECT{"opds:indirectAcquisition"};
+// static const QLatin1String OPDS_ATTR_FACET_GROUP{"opds:facetGroup"};
+// static const QLatin1String OPDS_ATTR_ACTIVE_FACET{"opds:activeFacet"};
 
 static const QLatin1String OPDS_ATOM_MT{"application/atom+xml"};
 static const QLatin1String OPDS_PROFILE{"profile=opds-catalog"};
 static const QLatin1String OPDS_TYPE_ENTRY{"type=entry"};
-static const QLatin1String OPDS_KIND_NAVIGATION{"kind=navigation"};
-static const QLatin1String OPDS_KIND_ACQUISITION{"kind=acquisition"};
+// static const QLatin1String OPDS_KIND_NAVIGATION{"kind=navigation"};
+// static const QLatin1String OPDS_KIND_ACQUISITION{"kind=acquisition"};
 
 static const QLatin1String REL_START{"start"};
-static const QLatin1String REL_SUBSECTION{"subsection"};
-static const QLatin1String REL_COLLECTION{"collection"};
-static const QLatin1String REL_PREVIEW{"preview"};
-static const QLatin1String REL_REPLIES{"replies"};
-static const QLatin1String REL_RELATED{"related"};
-static const QLatin1String REL_PREVIOUS{"previous"};
-static const QLatin1String REL_NEXT{"next"};
-static const QLatin1String REL_FIRST{"first"};
-static const QLatin1String REL_LAST{"last"};
+// static const QLatin1String REL_SUBSECTION{"subsection"};
+// static const QLatin1String REL_COLLECTION{"collection"};
+// static const QLatin1String REL_PREVIEW{"preview"};
+// static const QLatin1String REL_REPLIES{"replies"};
+// static const QLatin1String REL_RELATED{"related"};
+// static const QLatin1String REL_PREVIOUS{"previous"};
+// static const QLatin1String REL_NEXT{"next"};
+// static const QLatin1String REL_FIRST{"first"};
+// static const QLatin1String REL_LAST{"last"};
 static const QLatin1String REL_UP{"up"};
 static const QLatin1String REL_SELF{"self"};
 static const QLatin1String REL_ALTERNATE{"alternate"};
 static const QLatin1String ATTR_CURRENCY_CODE{"currencycode"};
-static const QLatin1String FEED_COMPLETE{"fh:complete"};
-static const QLatin1String THREAD_COUNT{"count"};
+// static const QLatin1String FEED_COMPLETE{"fh:complete"};
+// static const QLatin1String THREAD_COUNT{"count"};
 
 static const QLatin1String OPENSEARCH_NS{"http://a9.com/-/spec/opensearch/1.1/"};
 static const QLatin1String OPENSEARCH_MT{"application/opensearchdescription+xml"};
@@ -112,7 +111,7 @@ public:
 
     XmlLoader *xmlLoader;
 
-    EntryInternal::List cachedEntries;
+    Entry::List cachedEntries;
     Provider::SearchRequest currentRequest;
 
     QUrl openSearchDocumentURL;
@@ -149,7 +148,6 @@ public:
         QUrl query = QUrl(urlPart);
         if (query.isRelative()) {
             if (selfUrl.isEmpty() || QUrl(selfUrl).isRelative()) {
-                QUrl host = currentUrl;
                 return currentUrl.resolved(query);
             } else {
                 return QUrl(selfUrl).resolved(query);
@@ -158,9 +156,9 @@ public:
         return query;
     };
 
-    EntryInternal::List installedEntries() const {{EntryInternal::List entries;
-    for (const EntryInternal &entry : std::as_const(cachedEntries)) {
-        if (entry.status() == KNS3::Entry::Installed || entry.status() == KNS3::Entry::Updateable) {
+    Entry::List installedEntries() const {{Entry::List entries;
+    for (const Entry &entry : std::as_const(cachedEntries)) {
+        if (entry.status() == KNSCore::Entry::Installed || entry.status() == KNSCore::Entry::Updateable) {
             entries.append(entry);
         }
     }
@@ -221,7 +219,7 @@ void parseFeedData(const QDomDocument &doc)
         iconUrl = QUrl(fixRelativeUrl(feedDoc->icon()));
     }
 
-    EntryInternal::List entries;
+    Entry::List entries;
     QList<OPDSProvider::SearchPreset> presets;
 
     {
@@ -334,13 +332,13 @@ void parseFeedData(const QDomDocument &doc)
     for (int i = 0; i < feedDoc->entries().size(); i++) {
         Syndication::Atom::Entry feedEntry = feedDoc->entries().at(i);
 
-        EntryInternal entry;
+        Entry entry;
         entry.setName(feedEntry.title());
         entry.setProviderId(providerId);
         entry.setUniqueId(feedEntry.id());
 
-        entry.setStatus(KNS3::Entry::Invalid);
-        for (const EntryInternal &cachedEntry : std::as_const(cachedEntries)) {
+        entry.setStatus(KNSCore::Entry::Invalid);
+        for (const Entry &cachedEntry : std::as_const(cachedEntries)) {
             if (entry.uniqueId() == cachedEntry.uniqueId()) {
                 entry = cachedEntry;
                 break;
@@ -386,7 +384,7 @@ void parseFeedData(const QDomDocument &doc)
         for (int j = 0; j < feedEntry.links().size(); j++) {
             Syndication::Atom::Link link = feedEntry.links().at(j);
 
-            KNSCore::EntryInternal::DownloadLinkInformation download;
+            KNSCore::Entry::DownloadLinkInformation download;
             download.id = entry.downloadLinkCount() + 1;
             // Linkrelations can have multiple values, expressed as something like... rel="me nofollow alternate".
             QStringList linkRelation = link.rel().split(QStringLiteral(" "));
@@ -422,11 +420,11 @@ void parseFeedData(const QDomDocument &doc)
                 } else if (linkRelation.contains(OPDS_REL_ACQUISITION) || linkRelation.contains(OPDS_REL_AC_OPEN_ACCESS)) {
                     download.isDownloadtypeLink = true;
 
-                    if (entry.status() != KNS3::Entry::Installed && entry.status() != KNS3::Entry::Updateable) {
-                        entry.setStatus(KNS3::Entry::Downloadable);
+                    if (entry.status() != KNSCore::Entry::Installed && entry.status() != KNSCore::Entry::Updateable) {
+                        entry.setStatus(KNSCore::Entry::Downloadable);
                     }
 
-                    entry.setEntryType(EntryInternal::CatalogEntry);
+                    entry.setEntryType(Entry::CatalogEntry);
                 }
                 // TODO, support preview relation, but this requires we show that an entry is otherwise paid for in the UI.
 
@@ -439,10 +437,10 @@ void parseFeedData(const QDomDocument &doc)
 
             } else if (link.rel().startsWith(OPDS_REL_IMAGE)) {
                 if (link.rel() == OPDS_REL_THUMBNAIL) {
-                    entry.setPreviewUrl(linkUrl, KNSCore::EntryInternal::PreviewType(counterThumbnails));
+                    entry.setPreviewUrl(linkUrl, KNSCore::Entry::PreviewType(counterThumbnails));
                     counterThumbnails += 1;
                 } else {
-                    entry.setPreviewUrl(linkUrl, KNSCore::EntryInternal::PreviewType(counterImages + 3));
+                    entry.setPreviewUrl(linkUrl, KNSCore::Entry::PreviewType(counterImages + 3));
                     counterImages += 1;
                 }
 
@@ -478,7 +476,7 @@ void parseFeedData(const QDomDocument &doc)
             entry.setReleaseDate(date.date());
         }
 
-        if (entry.status() != KNS3::Entry::Invalid) {
+        if (entry.status() != KNSCore::Entry::Invalid) {
             entry.setPayload(QString());
             // Gutenberg doesn't do versioning in the opds, so it's update value is unreliable,
             // even though openlib and standard do use it properly. We'll instead doublecheck that
@@ -486,8 +484,8 @@ void parseFeedData(const QDomDocument &doc)
             if (date.secsTo(currentTime) > 360) {
                 if (entry.releaseDate() < date.date()) {
                     entry.setUpdateReleaseDate(date.date());
-                    if (entry.status() == KNS3::Entry::Installed) {
-                        entry.setStatus(KNS3::Entry::Updateable);
+                    if (entry.status() == KNSCore::Entry::Installed) {
+                        entry.setStatus(KNSCore::Entry::Updateable);
                     }
                 }
             }
@@ -503,7 +501,7 @@ void parseFeedData(const QDomDocument &doc)
             if (groupEntryUrl.isEmpty()) {
                 continue;
             } else {
-                entry.setEntryType(EntryInternal::GroupEntry);
+                entry.setEntryType(Entry::GroupEntry);
                 entry.setPayload(groupEntryUrl);
             }
         }
@@ -552,7 +550,7 @@ void OPDSProvider::loadEntries(const KNSCore::Provider::SearchRequest &request)
         Q_EMIT loadingFinished(request, d->installedEntries());
         return;
     } else if (request.filter == Provider::ExactEntryId) {
-        for (EntryInternal entry : d->cachedEntries) {
+        for (Entry entry : d->cachedEntries) {
             if (entry.uniqueId() == request.searchTerm) {
                 loadEntryDetails(entry);
             }
@@ -587,7 +585,7 @@ void OPDSProvider::loadEntries(const KNSCore::Provider::SearchRequest &request)
     }
 }
 
-void OPDSProvider::loadEntryDetails(const EntryInternal &entry)
+void OPDSProvider::loadEntryDetails(const Entry &entry)
 {
     QUrl url;
     QString entryMimeType = QStringList({OPDS_ATOM_MT, OPDS_TYPE_ENTRY, OPDS_PROFILE}).join(QStringLiteral(";"));
@@ -614,9 +612,9 @@ void OPDSProvider::loadEntryDetails(const EntryInternal &entry)
     }
 }
 
-void OPDSProvider::loadPayloadLink(const KNSCore::EntryInternal &entry, int linkNumber)
+void OPDSProvider::loadPayloadLink(const KNSCore::Entry &entry, int linkNumber)
 {
-    KNSCore::EntryInternal copy = entry;
+    KNSCore::Entry copy = entry;
     for (auto downloadInfo : entry.downloadLinkInformationList()) {
         if (downloadInfo.id == linkNumber) {
             for (QString string : downloadInfo.tags) {
@@ -663,8 +661,10 @@ bool OPDSProvider::isInitialized() const
     return d->initialized;
 }
 
-void OPDSProvider::setCachedEntries(const KNSCore::EntryInternal::List &cachedEntries)
+void OPDSProvider::setCachedEntries(const KNSCore::Entry::List &cachedEntries)
 {
     d->cachedEntries = cachedEntries;
 }
 }
+
+#include "moc_opdsprovider_p.cpp"
