@@ -9,8 +9,10 @@
 
 #include <QObject>
 #include <QQmlParserStatus>
-#include <entryinternal.h>
+#include <entry.h>
 
+// TODO This is not a class for exposing data QtQuick, but for implementing it's fetching in the first place.
+// Also it sepnds on the QML parser status, this is kindof ugly...
 namespace KNewStuffQuick
 {
 class AuthorPrivate;
