@@ -9,7 +9,7 @@
 
 #include <QQmlParserStatus>
 #include <QSortFilterProxyModel>
-#include <entryinternal.h>
+#include <entry.h>
 
 #include <memory>
 
@@ -89,5 +89,5 @@ private:
     const std::unique_ptr<CommentsModelPrivate> d;
 };
 }
-Q_DECLARE_METATYPE(KNewStuffQuick::CommentsModel::IncludedComments)
+
 #endif // KNSQUICK_COMMENTSMODEL_H
