@@ -10,7 +10,6 @@
 #include "categoriesmodel.h"
 #include "commentsmodel.h"
 #include "downloadlinkinfo.h"
-#include "entrywrapper.h"
 #include "quickengine.h"
 #include "quickitemsmodel.h"
 #include "quickquestionlistener.h"
@@ -24,9 +23,8 @@
 #include <QQmlEngine>
 #include <qqml.h>
 
-void QmlPlugins::initializeEngine(QQmlEngine *engine, const char *)
+void QmlPlugins::initializeEngine(QQmlEngine * /*engine*/, const char *)
 {
-    Q_UNUSED(engine);
 }
 
 void QmlPlugins::registerTypes(const char *uri)
@@ -40,12 +38,6 @@ void QmlPlugins::registerTypes(const char *uri)
     // Version 1.62
     qmlRegisterType<KNewStuffQuick::Author>(uri, 1, 62, "Author");
     qmlRegisterType<KNewStuffQuick::CommentsModel>(uri, 1, 62, "CommentsModel");
-    qmlRegisterUncreatableType<DownloadLinkInfo>(
-        uri,
-        1,
-        0,
-        "DownloadLinkInfo",
-        QStringLiteral("This should only be created by the ItemsModel, and is associated with one entry in that model"));
     qmlRegisterUncreatableType<CategoriesModel>(
         uri,
         1,
@@ -68,25 +60,15 @@ void QmlPlugins::registerTypes(const char *uri)
                                                                     1,
                                                                     62,
                                                                     "QuickQuestionListener",
-                                                                    [](QQmlEngine *engine, QJSEngine *scriptEngine) -> QObject * {
-                                                                        Q_UNUSED(scriptEngine)
+                                                                    [](QQmlEngine *engine, QJSEngine * /*scriptEngine*/) -> QObject * {
                                                                         engine->setObjectOwnership(KNewStuffQuick::QuickQuestionListener::instance(),
                                                                                                    QQmlEngine::CppOwnership);
                                                                         return KNewStuffQuick::QuickQuestionListener::instance();
                                                                     });
-    qmlRegisterUncreatableType<KNSCore::EntryInternal>(uri, 1, 91, "Entry", QStringLiteral("Entries should only be created by the engine"));
-
-    // Version 1.67
-    qmlRegisterUncreatableType<KNSCore::EntryWrapper>(
-        coreUri,
-        1,
-        67,
-        "EntryWrapper",
-        QStringLiteral("This should only be created by the Engine, and wraps EntryInternal objects for passing through Qt Quick"));
+    qmlRegisterUncreatableMetaObject(KNSCore::Entry::staticMetaObject, uri, 1, 91, "Entry", QStringLiteral("Entries should only be created by the engine"));
 
     // Version 1.81
-    qmlRegisterSingletonType<KNewStuffQuick::Settings>(uri, 1, 81, "Settings", [](QQmlEngine *engine, QJSEngine *scriptEngine) -> QObject * {
-        Q_UNUSED(scriptEngine)
+    qmlRegisterSingletonType<KNewStuffQuick::Settings>(uri, 1, 81, "Settings", [](QQmlEngine *engine, QJSEngine * /*scriptEngine*/) -> QObject * {
         engine->setObjectOwnership(KNewStuffQuick::Settings::instance(), QQmlEngine::CppOwnership);
         return KNewStuffQuick::Settings::instance();
     });
